@@ -2,16 +2,17 @@
 Initializing the Python package
 """
 
-from .model import Attribute
+from .model import Attribute, Extra
 from .main import make_base
 from .table import Table
 
 
-__version__ = '0.6'
+__version__ = '0.7'
 
 __all__ = (
     '__version__',
     'Attribute',
+    'Extra',
     'Table',
     'make_base',
 )
